@@ -4,16 +4,14 @@ Main interface for finspace service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_finspace import (
         Client,
         finspaceClient,
     )
 
-    session = boto3.Session()
-
-    client: finspaceClient = boto3.client("finspace")
-    session_client: finspaceClient = session.client("finspace")
+    session = Session()
+    client: finspaceClient = session.client("finspace")
     ```
 """
 from .client import finspaceClient
