@@ -1,7 +1,7 @@
 """
 Type annotations for finspace service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace/type_defs/)
 
 Usage::
 
@@ -44,19 +44,32 @@ __all__ = (
     "UpdateEnvironmentResponseTypeDef",
 )
 
-CreateEnvironmentRequestRequestTypeDef = TypedDict(
-    "CreateEnvironmentRequestRequestTypeDef",
+_RequiredCreateEnvironmentRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateEnvironmentRequestRequestTypeDef",
     {
         "name": str,
-        "description": NotRequired[str],
-        "kmsKeyId": NotRequired[str],
-        "tags": NotRequired[Mapping[str, str]],
-        "federationMode": NotRequired[FederationModeType],
-        "federationParameters": NotRequired["FederationParametersTypeDef"],
-        "superuserParameters": NotRequired["SuperuserParametersTypeDef"],
-        "dataBundles": NotRequired[Sequence[str]],
     },
 )
+_OptionalCreateEnvironmentRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateEnvironmentRequestRequestTypeDef",
+    {
+        "description": str,
+        "kmsKeyId": str,
+        "tags": Mapping[str, str],
+        "federationMode": FederationModeType,
+        "federationParameters": "FederationParametersTypeDef",
+        "superuserParameters": "SuperuserParametersTypeDef",
+        "dataBundles": Sequence[str],
+    },
+    total=False,
+)
+
+
+class CreateEnvironmentRequestRequestTypeDef(
+    _RequiredCreateEnvironmentRequestRequestTypeDef, _OptionalCreateEnvironmentRequestRequestTypeDef
+):
+    pass
+
 
 CreateEnvironmentResponseTypeDef = TypedDict(
     "CreateEnvironmentResponseTypeDef",
@@ -78,31 +91,33 @@ DeleteEnvironmentRequestRequestTypeDef = TypedDict(
 EnvironmentTypeDef = TypedDict(
     "EnvironmentTypeDef",
     {
-        "name": NotRequired[str],
-        "environmentId": NotRequired[str],
-        "awsAccountId": NotRequired[str],
-        "status": NotRequired[EnvironmentStatusType],
-        "environmentUrl": NotRequired[str],
-        "description": NotRequired[str],
-        "environmentArn": NotRequired[str],
-        "sageMakerStudioDomainUrl": NotRequired[str],
-        "kmsKeyId": NotRequired[str],
-        "dedicatedServiceAccountId": NotRequired[str],
-        "federationMode": NotRequired[FederationModeType],
-        "federationParameters": NotRequired["FederationParametersTypeDef"],
+        "name": str,
+        "environmentId": str,
+        "awsAccountId": str,
+        "status": EnvironmentStatusType,
+        "environmentUrl": str,
+        "description": str,
+        "environmentArn": str,
+        "sageMakerStudioDomainUrl": str,
+        "kmsKeyId": str,
+        "dedicatedServiceAccountId": str,
+        "federationMode": FederationModeType,
+        "federationParameters": "FederationParametersTypeDef",
     },
+    total=False,
 )
 
 FederationParametersTypeDef = TypedDict(
     "FederationParametersTypeDef",
     {
-        "samlMetadataDocument": NotRequired[str],
-        "samlMetadataURL": NotRequired[str],
-        "applicationCallBackURL": NotRequired[str],
-        "federationURN": NotRequired[str],
-        "federationProviderName": NotRequired[str],
-        "attributeMap": NotRequired[Mapping[str, str]],
+        "samlMetadataDocument": str,
+        "samlMetadataURL": str,
+        "applicationCallBackURL": str,
+        "federationURN": str,
+        "federationProviderName": str,
+        "attributeMap": Mapping[str, str],
     },
+    total=False,
 )
 
 GetEnvironmentRequestRequestTypeDef = TypedDict(
@@ -123,9 +138,10 @@ GetEnvironmentResponseTypeDef = TypedDict(
 ListEnvironmentsRequestRequestTypeDef = TypedDict(
     "ListEnvironmentsRequestRequestTypeDef",
     {
-        "nextToken": NotRequired[str],
-        "maxResults": NotRequired[int],
+        "nextToken": str,
+        "maxResults": int,
     },
+    total=False,
 )
 
 ListEnvironmentsResponseTypeDef = TypedDict(
@@ -188,16 +204,29 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateEnvironmentRequestRequestTypeDef = TypedDict(
-    "UpdateEnvironmentRequestRequestTypeDef",
+_RequiredUpdateEnvironmentRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateEnvironmentRequestRequestTypeDef",
     {
         "environmentId": str,
-        "name": NotRequired[str],
-        "description": NotRequired[str],
-        "federationMode": NotRequired[FederationModeType],
-        "federationParameters": NotRequired["FederationParametersTypeDef"],
     },
 )
+_OptionalUpdateEnvironmentRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateEnvironmentRequestRequestTypeDef",
+    {
+        "name": str,
+        "description": str,
+        "federationMode": FederationModeType,
+        "federationParameters": "FederationParametersTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateEnvironmentRequestRequestTypeDef(
+    _RequiredUpdateEnvironmentRequestRequestTypeDef, _OptionalUpdateEnvironmentRequestRequestTypeDef
+):
+    pass
+
 
 UpdateEnvironmentResponseTypeDef = TypedDict(
     "UpdateEnvironmentResponseTypeDef",
